@@ -4,11 +4,13 @@ from django_postgresql_dag.models import node_factory, edge_factory
 
 class EdgeSet(models.Model):
     """A model designed as a container for a set of edges"""
+
     name = models.CharField(max_length=100)
 
 
 class NodeSet(models.Model):
     """A model designed as a container for a set of nodes"""
+
     name = models.CharField(max_length=100)
 
 
@@ -25,7 +27,7 @@ class NetworkEdge(edge_factory("NetworkNode", concrete=False)):
         super().save(*args, **kwargs)
 
     class Meta:
-        app_label = 'tests'
+        app_label = "tests"
 
 
 class NetworkNode(node_factory(NetworkEdge)):
@@ -37,4 +39,4 @@ class NetworkNode(node_factory(NetworkEdge)):
         return self.name
 
     class Meta:
-        app_label = 'tests'
\ No newline at end of file
+        app_label = "tests"
